@@ -159,3 +159,39 @@ def is_ordered(thelist, reverse=False):
             if thelist[index] < thelist[index-1]:
                 return False
         return True
+
+def list2dict(thelist, fields):
+    """Turn list to dict, using keys in fields.
+
+    Examples:
+
+    In [1]: from fastutils import listutils
+
+    In [2]: listutils.list2dict([1,2,3], ['a', 'b'])
+    Out[2]: {'a': 1, 'b': 2}
+
+    In [3]: listutils.list2dict([1,2,3], ['a', 'b', 'c'])
+    Out[3]: {'a': 1, 'b': 2, 'c': 3}
+
+    In [4]: listutils.list2dict([1,2,3], ['a', 'b', 'c', 'd'])
+    Out[4]: {'a': 1, 'b': 2, 'c': 3, 'd': None}
+    """
+    result = {}
+    thelistlength = len(thelist)
+    field_infos = []
+    for field in fields:
+        if isinstance(field, str):
+            field_info = (field, None)
+        elif isinstance(field, (tuple, list)):
+            field_name = field[0]
+            if len(field) >= 2:
+                field_default = field[1]
+            field_info = (field_name, field_default)
+        field_infos.append(field_info)
+    for index, field_info in enumerate(field_infos):
+        if index < thelistlength:
+            result[field_info[0]] = thelist[index]
+        else:
+            result[field_info[0]] = field_info[1]
+    return result
+
