@@ -60,14 +60,20 @@ def load_public_key(text):
     if isinstance(text, (rsa.PublicKey, rsa.PrivateKey)):
         text = text.save_pkcs1()
     pk = RSA.import_key(text)
-    pk = pk.public_key()
+    if hasattr(pk, "public_key"):
+        pk = pk.public_key()
+    else:
+        pk = pk.publickey()
     return pk
 
 def load_public_key_from_private_key(text, passphrase=None):
     """Get public key from private key.
     """
     sk = load_private_key(text, passphrase)
-    pk = sk.publickey()
+    if hasattr(sk, "public_key"):
+        pk = sk.public_key()
+    else:
+        pk = sk.publickey()
     return pk
 
 def encrypt(data: bytes, pk: typing.Union[RSA.RsaKey, rsa.PublicKey, str], envelope=PKCS1_OAEP) -> str:
