@@ -7,6 +7,7 @@ import string
 import binascii
 import base64
 import typing
+from unittest import result
 import bizerror
 import math
 import re
@@ -789,3 +790,48 @@ def chunk(value:str, size:int) -> typing.List[str]:
         chunks.append(value[start:start+size])
         start += size
     return chunks
+
+
+def get_all_substrings(value):
+    """Get all substrings of the value.
+    
+    Examples:
+
+    In [4]: strutils.get_all_substrings('a')
+    Out[4]: {'a'}
+
+    In [5]: strutils.get_all_substrings('ab')
+    Out[5]: {'a', 'ab', 'b'}
+
+    In [6]: strutils.get_all_substrings('abc')
+    Out[6]: {'a', 'ab', 'abc', 'b', 'bc', 'c'}
+
+    In [7]: strutils.get_all_substrings('abcd')
+    Out[7]: {'a', 'ab', 'abc', 'abcd', 'b', 'bc', 'bcd', 'c', 'cd', 'd'}
+
+    In [8]: strutils.get_all_substrings('abcde')
+    Out[8]: 
+    {'a',
+    'ab',
+    'abc',
+    'abcd',
+    'abcde',
+    'b',
+    'bc',
+    'bcd',
+    'bcde',
+    'c',
+    'cd',
+    'cde',
+    'd',
+    'de',
+    'e'}
+    """
+    substrings = set()
+    for length in range(len(value)):
+        length += 1
+        for index in range(len(value)-length+1):
+            substring = value[index:index+length]
+            substrings.add(substring)
+    return substrings
+
